<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>CategoryDialog</name>
    <message>
        <location filename="../../category_dialog.ui" line="14"/>
        <source>Choose Category</source>
        <translation>Kies een categorie</translation>
    </message>
    <message>
        <location filename="../../category_dialog.ui" line="26"/>
        <source>&amp;Category</source>
        <translation>&amp;Categorie</translation>
    </message>
</context>
<context>
    <name>ConverterWindow</name>
    <message>
        <source>Unit Converter</source>
        <translation type="vanished">Einheitenkonvertierer</translation>
    </message>
    <message>
        <source>A&amp;mount</source>
        <translation type="vanished">&amp;Menge</translation>
    </message>
    <message>
        <source>&amp;Converted</source>
        <translation type="vanished">&amp;Konvertiert</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="14"/>
        <source>Convert Units</source>
        <translation>Omrekenen</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="22"/>
        <source>Amo&amp;unt</source>
        <translation>Hoeveelh&amp;eid</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="86"/>
        <source>Con&amp;verted</source>
        <translation>Omge&amp;rekend</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="102"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="79"/>
        <source>kg/l</source>
        <translation>kg/l</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="104"/>
        <source>rolled oats</source>
        <translation>havervlokken</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="105"/>
        <source>bread crumbs</source>
        <translation>broodkruimels</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="106"/>
        <source>desiccated coconut</source>
        <translation>kokosrasp</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="107"/>
        <source>cornflour</source>
        <translation>maïsmeel</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="108"/>
        <source>cocoa</source>
        <translation>cacao</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="109"/>
        <source>ground almonds</source>
        <translation>gehakte amandelen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="110"/>
        <source>shredded suet</source>
        <translation>gebroken vet</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="111"/>
        <source>sugar</source>
        <translation>suiker</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="112"/>
        <source>rice</source>
        <translation>rijst</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="113"/>
        <source>haricots</source>
        <translation>bonen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="114"/>
        <source>lentils</source>
        <translation>linzen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="115"/>
        <source>barley</source>
        <translation>gerst</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="116"/>
        <source>peas</source>
        <translation>erwten</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="117"/>
        <source>sultana</source>
        <translation>sultana</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="118"/>
        <source>tapioca</source>
        <translation>tapioca</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="119"/>
        <source>ground rice</source>
        <translation>gebroken rijst</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="120"/>
        <source>currants</source>
        <translation>bessen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="121"/>
        <source>semolina</source>
        <translation>griesmeel</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="122"/>
        <source>raisins</source>
        <translation>rozijnen</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="123"/>
        <source>custard powder</source>
        <translation>custardpoeder</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="124"/>
        <source>flour</source>
        <translation>bloem</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="125"/>
        <source>milk</source>
        <translation>melk</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="126"/>
        <source>icing sugar</source>
        <translation>poedersuiker</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="127"/>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <location filename="../../edit_dialog.ui" line="14"/>
        <source>Edit Recipe</source>
        <translation>Recept aanpassen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="28"/>
        <source>&amp;General</source>
        <translation>&amp;Algemeen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="36"/>
        <location filename="../../edit_dialog.ui" line="570"/>
        <source>&amp;Title:</source>
        <translation>&amp;Naam:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="56"/>
        <source>&amp;Categories:</source>
        <translation>&amp;Categorieën:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="73"/>
        <source>&amp;Yield:</source>
        <translation>Aantal &amp;porties:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="123"/>
        <source>&amp;Ingredients</source>
        <translation>&amp;Ingrediënten</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="220"/>
        <source>I&amp;ngredient</source>
        <translation>I&amp;ngrediënt</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="146"/>
        <source>Add &amp;Group</source>
        <translation>&amp;Groep toevoegen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="153"/>
        <source>Add &amp;Ingredient</source>
        <translation>&amp;Ingrediënt toevoegen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="160"/>
        <location filename="../../edit_dialog.ui" line="654"/>
        <source>&amp;Remove</source>
        <translation>Ve&amp;rwijderen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="167"/>
        <location filename="../../edit_dialog.ui" line="661"/>
        <source>&amp;Up</source>
        <translation>&amp;Omhoog</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="178"/>
        <location filename="../../edit_dialog.ui" line="672"/>
        <source>&amp;Down</source>
        <translation>Om&amp;laag</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="226"/>
        <source>A&amp;mount:</source>
        <translation>&amp;Hoeveelheid:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="244"/>
        <source>float</source>
        <translation>zwevende komma</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="239"/>
        <source>fraction</source>
        <translation>breuk</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="49"/>
        <location filename="../../edit_dialog.ui" line="717"/>
        <source>title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="66"/>
        <source>category1, category2, ...</source>
        <translation>categorie1, categorie2, ...</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="98"/>
        <source>servings</source>
        <translation>aantal porties</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="189"/>
        <source>U&amp;nit Converter</source>
        <translation>Omreke&amp;nen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="284"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="301"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="359"/>
        <source>Uni&amp;t:</source>
        <translation>Eenhei&amp;d:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="370"/>
        <source>per serving</source>
        <translation>per portie</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="375"/>
        <source>small</source>
        <translation>klein</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="380"/>
        <source>medium</source>
        <translation>gemiddeld</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="385"/>
        <source>large</source>
        <translation>groot</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="390"/>
        <source>can</source>
        <translation>blik</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="395"/>
        <source>package</source>
        <translation>pakje</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="400"/>
        <source>pinch</source>
        <translation>snufje</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="405"/>
        <source>drop</source>
        <translation>druppel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="410"/>
        <source>dash</source>
        <translation>tikkeltje</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="415"/>
        <source>carton</source>
        <translation>drinkpak</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="420"/>
        <source>bunch</source>
        <translation>bundel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="425"/>
        <source>slice</source>
        <translation>schijfje</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="430"/>
        <source>each</source>
        <translation>per stuk</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="435"/>
        <source>teaspoon</source>
        <translation>theelepel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="440"/>
        <source>tablespoon</source>
        <translation>eetlepel</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="445"/>
        <source>fluid ounce</source>
        <translation>vloeibaar ons</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="450"/>
        <source>cup</source>
        <translation>beker</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="455"/>
        <source>pint</source>
        <translation>mespunt</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="460"/>
        <source>quart</source>
        <translation>kwart</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="465"/>
        <source>gallon</source>
        <translation>gallon</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="470"/>
        <source>ounce</source>
        <translation>ons</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="475"/>
        <source>pound</source>
        <translation>pond</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="480"/>
        <source>milliliter</source>
        <translation>milliliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="485"/>
        <source>cubic cm</source>
        <translation>kubieke cm</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="490"/>
        <source>centiliter</source>
        <translation>centiliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="495"/>
        <source>deciliter</source>
        <translation>deciliter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="500"/>
        <source>liter</source>
        <translation>liter</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="505"/>
        <source>milligram</source>
        <translation>milligram</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="510"/>
        <source>centigram</source>
        <translation>centigram</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="515"/>
        <source>decigram</source>
        <translation>decigram</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="520"/>
        <source>gram</source>
        <translation>gram</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="525"/>
        <source>kilogram</source>
        <translation>kilogram</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="538"/>
        <source>Na&amp;me:</source>
        <translation>Naa&amp;m:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="562"/>
        <source>Ingredient &amp;Section</source>
        <translation>Ingrediënten&amp;sectie</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="609"/>
        <source>Select section or ingredient</source>
        <translation>Kies een sectie of ingrediënt</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="693"/>
        <source>Instruction</source>
        <translation>Bereiding</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="701"/>
        <source>&amp;Title</source>
        <translation>&amp;Naam</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="755"/>
        <source>&amp;Ok</source>
        <translation>&amp;Oké</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="765"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Afbreken</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="624"/>
        <source>In&amp;structions</source>
        <translation>Bereiding&amp;swijze</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="647"/>
        <source>&amp;Add Group</source>
        <translation>&amp;Groep toevoegen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="548"/>
        <location filename="../../edit_dialog.cc" line="220"/>
        <source>ingredient</source>
        <translation>ingrediënt</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.cc" line="242"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../../export_dialog.ui" line="14"/>
        <source>Export MealMaster Recipes</source>
        <translation>MealMaster-recepten exporteren</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="26"/>
        <source>En&amp;coding</source>
        <translation>Teken&amp;set</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Foutenbes&amp;tand</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/fouten.mmf</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>Foutenbe&amp;stand kiezen</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="141"/>
        <source>Proceed with selection of output file</source>
        <translation>Uitvoerbestand kiezen</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleren</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Kies het foutenbestand</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Tekst (*.txt *.TXT);;Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../../import_dialog.ui" line="14"/>
        <source>Import MealMaster Recipes</source>
        <translation>MealMaster-recepten importeren</translation>
    </message>
    <message>
        <source>En&amp;coding</source>
        <translation type="vanished">&amp;Zeichensatz</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="26"/>
        <source>Encodin&amp;g</source>
        <translation>Teken&amp;set</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Foutenbes&amp;tand</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/fouten.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>Foutenbe&amp;stand kiezen</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="141"/>
        <source>Pr&amp;oceed with selection of recipes</source>
        <translation>Recepten sel&amp;ecteren</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleren</translation>
    </message>
    <message>
        <source>errors.mmf</source>
        <translation type="vanished">fouten.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Kies het foutenbestand</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Tekst (*.txt *.TXT);;Alle bestanden (*)</translation>
    </message>
</context>
<context>
    <name>IngredientModel</name>
    <message>
        <location filename="../../ingredient_model.cc" line="43"/>
        <source>amount</source>
        <translation>hoeveelheid</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="45"/>
        <source>unit</source>
        <translation>eenheid</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="47"/>
        <source>ingredient</source>
        <translation>ingrediënt</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="76"/>
        <location filename="../../ingredient_model.cc" line="215"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Hoofd&gt;</translation>
    </message>
</context>
<context>
    <name>InstructionsModel</name>
    <message>
        <location filename="../../instructions_model.cc" line="52"/>
        <location filename="../../instructions_model.cc" line="62"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Hoofd&gt;</translation>
    </message>
    <message>
        <location filename="../../instructions_model.cc" line="78"/>
        <source>section</source>
        <translation>sectie</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main_window.ui" line="14"/>
        <source>AnyMeal</source>
        <translation>AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="27"/>
        <source>&amp;Show all recipes</source>
        <translation>Alle re&amp;cepten tonen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="34"/>
        <source>&amp;Title</source>
        <translation>&amp;Naam</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="44"/>
        <source>Search for title text.</source>
        <translation>Zoek naar receptnamen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="74"/>
        <source>&amp;Category</source>
        <translation>&amp;Categorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="84"/>
        <source>Search for categories.</source>
        <translation>Zoek naar categorieën</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="94"/>
        <source>Search for recipes with ingredient.</source>
        <translation>Zoek naar recepten met een bepaald ingrediënt</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="54"/>
        <location filename="../../main_window.ui" line="97"/>
        <source>w</source>
        <translation>met</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="107"/>
        <source>Search for recipes without ingredient.</source>
        <translation>Zoek naar recepten zonder specifiek ingrediënt</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="64"/>
        <location filename="../../main_window.ui" line="110"/>
        <source>w/o</source>
        <translation>zonder</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="120"/>
        <source>&amp;Ingredient</source>
        <translation>&amp;ingrediënt</translation>
    </message>
    <message>
        <source>&amp;Filter</source>
        <translation type="vanished">&amp;Filtern</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="201"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="214"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="vanished">toolBar</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="264"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="270"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="279"/>
        <source>&amp;Import recipes</source>
        <translation>Recepten &amp;importeren</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="vanished">&amp;Importieren</translation>
    </message>
    <message>
        <source>tool bar</source>
        <translation type="vanished">Werkzeugleiste</translation>
    </message>
    <message>
        <source>Categor&amp;y</source>
        <translation type="vanished">Kategor&amp;ie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="130"/>
        <source>Specify the ingredient.</source>
        <translation>Geef een ingrediënt op</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="137"/>
        <source>&amp;Search</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="221"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="236"/>
        <source>Tool Bar</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="267"/>
        <source>Exit application</source>
        <translation>Sluit het programma af</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="282"/>
        <source>Read MealMaster recipes from files</source>
        <translation>Lees MealMaster-recepten uit uit bestanden</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="285"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="294"/>
        <source>Print p&amp;review</source>
        <translation>Afd&amp;rukvoorbeeld</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="297"/>
        <source>Print preview of current recipe</source>
        <translation>Toon een afdrukvoorbeeld van het huidige recept</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="300"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="309"/>
        <source>&amp;Print recipe</source>
        <translation>Rece&amp;pt afdrukken</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="312"/>
        <source>Print current recipe</source>
        <translation>Druk het huidige recept af</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="315"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="324"/>
        <source>A&amp;bout AnyMeal</source>
        <translation>Over AnyMea&amp;l</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="327"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="336"/>
        <source>&amp;Delete recipes</source>
        <translation>Recept(en) verwij&amp;deren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="339"/>
        <source>Delete selected recipes</source>
        <translation>Verwijder de geselecteerde recepten</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="342"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="351"/>
        <source>Exp&amp;ort recipes</source>
        <translation>Recepten exp&amp;orteren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="354"/>
        <source>Write MealMaster recipes to file</source>
        <translation>Sla MealMaster-recepten op in een bestand</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="357"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="366"/>
        <source>&amp;Edit Recipe</source>
        <translation>Recept aanpass&amp;en</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="369"/>
        <source>Edit current recipe</source>
        <translation>Pas het huidige recept aan</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="381"/>
        <source>Collect &amp;Garbage</source>
        <translation>Opsc&amp;honen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="384"/>
        <source>Delete unused categories and ingredients</source>
        <translation>Verwijder ongebruikte categorieën en ingrediënten</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="387"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="396"/>
        <source>Add &amp;to Category</source>
        <translation>Toevoegen aan ca&amp;tegorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="402"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="411"/>
        <source>&amp;Remove from Category</source>
        <translation>Verwi&amp;jderen uit categorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="414"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="423"/>
        <source>Open Co&amp;nverter Window</source>
        <translation>Omreke&amp;nvenster openen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="426"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="453"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="435"/>
        <source>Remove duplicates</source>
        <translation>Verwijder duplicaten</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="438"/>
        <source>Remove duplicates in selected recipes</source>
        <translation>Verwijder duplicaten in geselecteerde recepten</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="447"/>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="450"/>
        <source>New recipe</source>
        <translation>Nieuw recept</translation>
    </message>
    <message>
        <source>&amp;Add to Category</source>
        <translation type="vanished">Zur K&amp;ategory Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="399"/>
        <source>Add selected recipes to a category</source>
        <translation>Voeg de geselecteerde recepten toe aan een categorie</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation type="vanished">Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Export recipes</source>
        <translation type="vanished">Rezepte &amp;Exportieren</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="372"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="92"/>
        <source>Error Opening Database</source>
        <translation>Fout tijdens openen van databank</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <source>Import MealMaster Files</source>
        <translation>MealMaster-bestanden importeren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <location filename="../../main_window.cc" line="438"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Tekst (*.txt *.TXT);;Alle bestanden (*)</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <source>Importing files ...</source>
        <translation>Bezig met importeren...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <location filename="../../main_window.cc" line="445"/>
        <location filename="../../main_window.cc" line="546"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <source>Processing file %1 ...</source>
        <translation type="vanished">Verarbeite Datei %1 ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="123"/>
        <source>%1 imported and %2 failed ...</source>
        <translation>%1 geïmporteerd; %2 overgeslagen...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="137"/>
        <source>Rejected recipe: </source>
        <translation>Overgeslagen recept: </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="142"/>
        <location filename="../../main_window.cc" line="469"/>
        <location filename="../../main_window.cc" line="477"/>
        <source>Error writing to file </source>
        <translation>Kan bestand niet wegschrijven: </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>Recipes Imported</source>
        <translation>Recepten geïmporteerd</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>%1 imported and %2 failed.</source>
        <translation>%1 geïmporteerd; %2 overgeslagen.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="167"/>
        <source>Error While Importing</source>
        <translation>Fout tijdens importeren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="178"/>
        <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
        <translation>Wilt u het huidige recept aanpassen, een kopie ervan, een nieuw recept samenstellen of annuleren?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="179"/>
        <source>&amp;Edit Current</source>
        <translation>Huidig&amp;e recept aanpassen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="180"/>
        <source>Edit C&amp;opy</source>
        <translation>&amp;Kopie aanpassen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="181"/>
        <source>Edit &amp;New</source>
        <translation>&amp;Nieuw recept samenstellen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="250"/>
        <source>Error While Updating Recipe</source>
        <translation>Fout tijdens bijwerken van recepten</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="275"/>
        <source>Error Adding Recipes to Category</source>
        <translation>Fout tijdens toevoegen van recepten aan categorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="301"/>
        <source>Error Removing Recipes from Category</source>
        <translation>Fout tijdens verwijderen van recepten uit categorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="320"/>
        <source>Error Collecting Garbage</source>
        <translation>Fout tijdens opschonen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="464"/>
        <source>Failed recipe: </source>
        <translation>Mislukt recept:</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="546"/>
        <source>Detecting duplicates ...</source>
        <translation>Duplicaten detecteren ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="549"/>
        <source>Found %1 duplicates ...</source>
        <translation>%1 duplicaten gevonden</translation>
    </message>
    <message>
        <source>About AnyMeal</source>
        <translation type="vanished">Über AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="98"/>
        <source>Showing %1 recipes ...</source>
        <translation>Er worden %1 recepten getoond...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="182"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="329"/>
        <source>About AnyMeal %1</source>
        <translation>Over AnyMeal %1</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="374"/>
        <source>Error Filtering Recipes</source>
        <translation>Fout tijdens filteren van recepten</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="388"/>
        <source>Error Resetting Selection</source>
        <translation>Fout tijdens herstellen van selectie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="408"/>
        <source>Error fetching recipe</source>
        <translation>Fout tijdens ophalen van recept</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="438"/>
        <source>Export MealMaster File</source>
        <translation>MealMaster-bestand exporteren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="445"/>
        <source>Exporting recipes ...</source>
        <translation>Bezig met exporteren...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="480"/>
        <source>%1 exported and %2 failed ...</source>
        <translation>%1 geëxporteerd; %2 overgeslagen...</translation>
    </message>
    <message>
        <source>%1 exported and %2 failed</source>
        <translation type="vanished">%1 exportiert und %2 fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>Recipes Exported</source>
        <translation>Recepten geëxporteerd</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>%1 exported and %2 failed.</source>
        <translation>%1 geëxporteerd; %2 overgeslagen.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="487"/>
        <source>Error While Exporting</source>
        <translation>Fout tijdens exporteren</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Delete Recipes</source>
        <translation>Recepten verwijderen</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Do you want to delete the selected recipes?</source>
        <translation>Weet u zeker dat u de geselecteerde recepten wilt verwijderen?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="514"/>
        <source>Error Deleting Recipes</source>
        <translation>Fout tijdens verwijderen van recepten</translation>
    </message>
</context>
<context>
    <name>recipe</name>
    <message>
        <location filename="../../html.cc" line="183"/>
        <source>Categories</source>
        <translation>Categorieën</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="192"/>
        <source>Yield</source>
        <translation>Aantal porties</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="196"/>
        <source>Ingredients</source>
        <translation>Ingrediënten</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="199"/>
        <source>amount</source>
        <translation>hoeveelheid</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="200"/>
        <source>unit</source>
        <translation>eenheid</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="201"/>
        <source>ingredient</source>
        <translation>ingrediënt</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="221"/>
        <source>Instructions</source>
        <translation>Bereidingswijze</translation>
    </message>
</context>
<context>
    <name>units</name>
    <message>
        <location filename="../../html.cc" line="60"/>
        <source>per serving</source>
        <translation>per portie</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="61"/>
        <source>small</source>
        <translation>klein</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="62"/>
        <source>medium</source>
        <translation>gemiddeld</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="63"/>
        <source>large</source>
        <translation>groot</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="64"/>
        <source>can</source>
        <translation>blik</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="65"/>
        <source>package</source>
        <translation>pakje</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="66"/>
        <source>pinch</source>
        <translation>snufje</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="67"/>
        <source>drop</source>
        <translation>druppel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="68"/>
        <source>dash</source>
        <translation>tikkeltje</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="69"/>
        <source>carton</source>
        <translation>drinkpak</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="70"/>
        <source>bunch</source>
        <translation>bundel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="71"/>
        <source>slice</source>
        <translation>schijfje</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="72"/>
        <source>each</source>
        <translation>per stuk</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="73"/>
        <location filename="../../html.cc" line="74"/>
        <source>teaspoon</source>
        <translation>theelepel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="75"/>
        <location filename="../../html.cc" line="76"/>
        <source>tablespoon</source>
        <translation>eetlepel</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="77"/>
        <source>fluid ounce</source>
        <translation>vloeibaar ons</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="78"/>
        <source>cup</source>
        <translation>beker</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="79"/>
        <source>pint</source>
        <translation>mespunt</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="80"/>
        <source>quart</source>
        <translation>kwart</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="81"/>
        <source>gallon</source>
        <translation>gallon</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="82"/>
        <source>ounce</source>
        <translation>ons</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="83"/>
        <source>pound</source>
        <translation>pond</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="84"/>
        <source>milliliter</source>
        <translation>milliliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="85"/>
        <source>cubic cm</source>
        <translation>kubieke cm</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="86"/>
        <source>centiliter</source>
        <translation>centiliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="87"/>
        <source>deciliter</source>
        <translation>deciliter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="88"/>
        <source>liter</source>
        <translation>liter</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="89"/>
        <source>milligram</source>
        <translation>milligram</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="90"/>
        <source>centigram</source>
        <translation>centigram</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="91"/>
        <source>decigram</source>
        <translation>decigram</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="92"/>
        <source>gram</source>
        <translation>gram</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="93"/>
        <source>kilogram</source>
        <translation>kilogram</translation>
    </message>
</context>
</TS>
